camelot.camelot.model.authentication.ContactMechanism

Package camelot :: Package camelot :: Package model :: Module authentication :: Class ContactMechanism |
[hide private]
[frames] | no frames]

# Class ContactMechanism

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
__unicode__(self) | source code

Class Variables | [hide private]
| mechanism = `Field(camelot.types.VirtualAddress(256), required=`...``
| party_address = `ManyToOne('PartyAddress', ondelete= 'set null'`...``

Class Variable Details | [hide private]

  ### mechanism Value:
      Field(camelot.types.VirtualAddress(256), required= True)

  ### party_address Value:
      ManyToOne('PartyAddress', ondelete= 'set null', onupdate= 'cascade')